@@ -21,6 +21,12 @@ from everviz.plugins.crossplot.layout.crossplot_layout import get_sidebar_layout
 
 
 class CrossplotIndexed(WebvizPluginABC):
+    """
+    The CrossplotIndexed class implements a plugin for Webviz, which can plot
+    any indexed control from the data exported by Everest against any other
+    indexed control.
+    """
+
     def __init__(self, app, data_path, title="Indexed Crossplot"):
         super().__init__()
         self.title = title
@@ -138,6 +144,19 @@ class CrossplotIndexed(WebvizPluginABC):
             except IndexError:
                 return None
 
+        @app.callback(self.plugin_data_output, [self.plugin_data_requested])
+        def user_download_data(data_requested):
+            if data_requested:
+                return WebvizPluginABC.plugin_data_compress(
+                    [
+                        {
+                            "filename": Path(self.data_path).name,
+                            "content": get_data(self.data_path).to_csv(),
+                        }
+                    ]
+                )
+            return ""
+
         @app.callback(
             Output(self.graph_id, "figure"),
             [
